//
// Cforall Version 1.0.0 Copyright (C) 2015 University of Waterloo
//
// The contents of this file are covered under the licence agreement in the
// file "LICENCE" distributed with Cforall.
//
// ForExprMutator.cc --
//
// Author           : Rodolfo G. Esteves
// Created On       : Mon May 18 07:44:20 2015
// Last Modified By : Peter A. Buhr
// Last Modified On : Thu Aug 17 15:32:46 2017
// Update Count     : 11
//

#include <list>                 // for list, _List_iterator, list<>::iterator

#include "ForExprMutator.h"
#include "SynTree/Label.h"      // for Label
#include "SynTree/Statement.h"  // for Statement (ptr only), ForStmt, Compou...

namespace ControlStruct {
	Statement *ForExprMutator::postmutate( IfStmt *ifStmt ) {
		std::list<Statement *> &init = ifStmt->get_initialization();
		if ( init.size() == 0 ) {
			return ifStmt;
		} // if

		// create compound statement, move initializers outside, leave _for_ as-is
		CompoundStmt *block = new CompoundStmt( std::list< Label >() );
		std::list<Statement *> &stmts = block->get_kids();
		stmts.splice( stmts.end(), init );

		// add for to the new block
		stmts.push_back( ifStmt );
		return block;
	}

	Statement *ForExprMutator::postmutate( ForStmt *forStmt ) {
		// hoist any initializer declarations to make them C89 (rather than C99)
		std::list<Statement *> &init = forStmt->get_initialization();
		if ( init.size() == 0 ) {
			return forStmt;
		} // if

		// create compound statement, move initializers outside, leave _for_ as-is
		CompoundStmt *block = new CompoundStmt( std::list< Label >() );
		std::list<Statement *> &stmts = block->get_kids();
		stmts.splice( stmts.end(), init );

		// add for to the new block
		stmts.push_back( forStmt );
		return block;
	}
} // namespace ControlStruct

// Local Variables: //
// tab-width: 4 //
// mode: c++ //
// compile-command: "make install" //
// End: //
